==> bibledit_1.7.orig.tar.gz: bibledit-1.7/src/dialogentry.h <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGENTRY_H
#define INCLUDED_DIALOGENTRY_H


#include <gtk/gtk.h>
#include "configuration.h"
#include "ustring.h"


class EntryDialog
{
public:
  EntryDialog (const ustring& title, const ustring& info, const ustring& value);
  virtual ~EntryDialog ();
  virtual int run ();
  ustring entered_value;
protected:
  GtkWidget *entrydialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *label;
  GtkWidget *entry;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton;
  GtkWidget *okbutton;
private:
  static void on_okbutton_clicked (GtkButton *button, gpointer user_data);
  virtual void on_okbutton ();
  static void on_entry_changed (GtkEditable *editable, gpointer user_data);
  virtual void on_entry ();
};


#endif

==> bibledit-3.4.tar.gz: bibledit-3.4/src/dialogentry.h <==
/*
** Copyright (©) 2003-2008 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc.,  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**  
*/


#ifndef INCLUDED_DIALOGENTRY_H
#define INCLUDED_DIALOGENTRY_H


#include <gtk/gtk.h>
#include "ustring.h"


class EntryDialog
{
public:
  EntryDialog (const ustring& title, const ustring& info, const ustring& value);
  ~EntryDialog ();
  int run ();
  ustring entered_value;
  bool always_ok;
  void text_invisible ();
protected:
  GtkWidget *entrydialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *label;
  GtkWidget *entry;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton;
  GtkWidget *okbutton;
private:
  static void on_okbutton_clicked (GtkButton *button, gpointer user_data);
  void on_okbutton ();
  static void on_entry_changed (GtkEditable *editable, gpointer user_data);
  void on_entry ();
};


#endif
